@@ -14,6 +14,7 @@
 
 #include "remotedesktop.h"
 #include "screencast.h"
+#include "waylandintegration.h"
 
 class Session : public QDBusVirtualObject
 {
@@ -70,12 +71,22 @@ public:
         return m_persistMode;
     }
 
+    WaylandIntegration::Streams streams() const
+    {
+        return m_streams;
+    }
+    void setStreams(const WaylandIntegration::Streams &streams)
+    {
+        m_streams = streams;
+    }
+
 private:
     bool m_multipleSources;
     ScreenCastPortal::CursorModes m_cursorMode;
     ScreenCastPortal::SourceType m_types;
     ScreenCastPortal::PersistMode m_persistMode = ScreenCastPortal::NoPersist;
 
+    WaylandIntegration::Streams m_streams;
     QVariant m_restoreData;
 };
 
